==================
``psyclone.tests``
==================

.. automodule:: psyclone.tests

   .. contents::
      :local:


Submodules
==========

.. toctree::

   psyclone.tests.alggen_test
   psyclone.tests.config_test
   psyclone.tests.conftest
   psyclone.tests.core
   psyclone.tests.dependency_test
   psyclone.tests.dynamo0p3_basis_test
   psyclone.tests.dynamo0p3_cma_test
   psyclone.tests.dynamo0p3_haloex_test
   psyclone.tests.dynamo0p3_lma_test
   psyclone.tests.dynamo0p3_multigrid_test
   psyclone.tests.dynamo0p3_quadrature_test
   psyclone.tests.dynamo0p3_stubgen_test
   psyclone.tests.dynamo0p3_test
   psyclone.tests.dynkern_test
   psyclone.tests.errors_test
   psyclone.tests.exceptions_test
   psyclone.tests.expression_test
   psyclone.tests.f2pygen_test
   psyclone.tests.gen_kernel_stub_test
   psyclone.tests.generator_test
   psyclone.tests.gocean1p0_build
   psyclone.tests.gocean1p0_config_test
   psyclone.tests.gocean1p0_stencil_test
   psyclone.tests.gocean1p0_test
   psyclone.tests.kernel_tools_test
   psyclone.tests.lfric_build
   psyclone.tests.lfric_ref_elem_test
   psyclone.tests.line_length_test
   psyclone.tests.nemo
   psyclone.tests.parse
   psyclone.tests.psyGen_test
   psyclone.tests.psyir
   psyclone.tests.test_files
   psyclone.tests.utilities
   psyclone.tests.utilities_test

.. currentmodule:: psyclone.tests
